package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.UseGuideMapper;
import com.ruoyi.system.domain.UseGuide;
import com.ruoyi.system.service.IUseGuideService;

/**
 * 使用指南Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-07-14
 */
@Service
public class UseGuideServiceImpl implements IUseGuideService 
{
    @Autowired
    private UseGuideMapper useGuideMapper;

    /**
     * 查询使用指南
     * 
     * @param id 使用指南主键
     * @return 使用指南
     */
    @Override
    public UseGuide selectUseGuideById(Long id)
    {
        return useGuideMapper.selectUseGuideById(id);
    }

    /**
     * 查询使用指南列表
     * 
     * @param useGuide 使用指南
     * @return 使用指南
     */
    @Override
    public List<UseGuide> selectUseGuideList(UseGuide useGuide)
    {
        return useGuideMapper.selectUseGuideList(useGuide);
    }

    /**
     * 新增使用指南
     * 
     * @param useGuide 使用指南
     * @return 结果
     */
    @Override
    public int insertUseGuide(UseGuide useGuide)
    {
        useGuide.setCreateTime(DateUtils.getNowDate());
        return useGuideMapper.insertUseGuide(useGuide);
    }

    /**
     * 修改使用指南
     * 
     * @param useGuide 使用指南
     * @return 结果
     */
    @Override
    public int updateUseGuide(UseGuide useGuide)
    {
        useGuide.setUpdateTime(DateUtils.getNowDate());
        return useGuideMapper.updateUseGuide(useGuide);
    }

    /**
     * 批量删除使用指南
     * 
     * @param ids 需要删除的使用指南主键
     * @return 结果
     */
    @Override
    public int deleteUseGuideByIds(Long[] ids)
    {
        return useGuideMapper.deleteUseGuideByIds(ids);
    }

    /**
     * 删除使用指南信息
     * 
     * @param id 使用指南主键
     * @return 结果
     */
    @Override
    public int deleteUseGuideById(Long id)
    {
        return useGuideMapper.deleteUseGuideById(id);
    }

    @Override
    public AjaxResult getInfoNew() {

        UseGuide useGuide = useGuideMapper.getInfoNew();
        if(useGuide == null){
            useGuide = new UseGuide();
        }
        return AjaxResult.success("访问成功",useGuide);
    }
}
